pyxmpp.interface

Package pyxmpp :: Module interface |
[hide private]

# Module interface

source code

Interface API.

If zope.interface is available this module will be its equivalent, otherwise minimum interface API (partially compatible with zope.interface) will be defined here.

When full ZopeInterfaces API is needed impoer zope.interface instead of this module.

Classes | [hide private]
| Attribute

Functions | [hide private]
providedBy(ob) | source code
implementedBy(cls) | source code
implements(*interfaces) | source code

Variables | [hide private]
| __revision__ = ``'``$Id: utils.py 647 2006-08-26 18:27:39Z jajcus $``'``
| Interface = `<InterfaceClass pyxmpp.inteface_micro_impl.Interface>`
| __package__ = ``'``pyxmpp``'``